# OCSF Extensions Registry
The purpose of this file is to keep track of and avoid collisions in Extension `names` & `uid`s.

| Caption     | Name     | UID | Notes |
|-------------|----------|-----|-------|
| US GOV      | usg1     | **990** | The USG-1 schema extension |
| Cisco       | cisco    | **991** | The Cisco schema extension |
| Sedara      | sedara   | **992** | The Sedara schema extension |
| Sciber      | sciber   | **993** | The Sciber schema extension |
| DataBee     | databee  | **994** | The Comcast DataBee schema extension |
| Symantec    | symantec | **995** | The Symantec schema extension |
| SentinelOne | s1       | **996** | The SentinelOne schema extension |
| Splunk      | splunk   | **997** | The Splunk schema extension |
| AWS         | aws      | **998** | The Amazon Web Services schema extension |
| Development | dev      | **999** | The development (TODO) schema extensions |
| _Native Extensions defined in OCSF_ |
| Linux       | linux    | **1** | The Linux extension defines Linux specific attributes, objects and classes |
| Windows     | win      | **2** | The Windows extension defines Windows specific attributes, objects and classes |
| macOS       | macos    | **3** | The macOS extension defines macOS specific attributes, objects and classes |
